(*
	SM.mod
		Classes model file for the Standard Model
		by Hagen Eck and Sepp Kueblbeck 1995
		last modified 8 May 14 by Thomas Hahn


Modified to a simple broken QED theory, Stefan Liebler, Dec. 2019
*)

IndexRange[ Index[Generation] ] = Range[3]

IndexRange[ Index[Colour] ] = NoUnfold[Range[3]]

IndexStyle[ Index[Generation, i_Integer] ] := Alph[i + 8]

MaxGenerationIndex = 3

M$ClassesDescription = {

	(* Fermion *)
  F[1] == {
	SelfConjugate -> False,
	Indices -> {Index[Generation]},
	Mass -> MLF,
	QuantumNumbers -> {-1 Charge, LeptonNumber},
	PropagatorLabel -> ComposedChar["f", Index[Generation]],
	PropagatorType -> Straight,
	PropagatorArrow -> Forward },

  V[1] == {
	SelfConjugate -> True, 
	Indices -> {},
	Mass -> MA,
	PropagatorLabel -> "A",
	PropagatorType -> Sine,
	PropagatorArrow -> None },

	(* physical Higgs: Q = 0 *) 
  S[1] == {
	SelfConjugate -> True,
	Indices -> {},
	Mass -> MH,
	PropagatorLabel -> "H",
	PropagatorType -> ScalarDash,
	PropagatorArrow -> None },

	(* unphysical Higgs: neutral Goldstone *) 
  S[2] == {
	SelfConjugate -> True,
	Indices -> {},
	Mass -> MA,
	PropagatorLabel -> ComposedChar["G", Null, "0"],
	PropagatorType -> ScalarDash,
	PropagatorArrow -> None }
}

MLF[1] = MF;
MLF[2] = MF;
MLF[3] = MF;
TheLabel[ F[1, {1}] ] = "F1"; 
TheLabel[ F[1, {2}] ] = "F2"; 
TheLabel[ F[1, {3}] ] = "F3";

GaugeXi[ V[1] ] = Xi;
GaugeXi[ S[1] ] = 1;
GaugeXi[ S[2] ] = Xi;

M$CouplingMatrices = {

  C[ -F[1, {j1}], F[1, {j2}], V[1] ] == - I ele *
    { {IndexDelta[j1, j2],0},{0,0} },

  C[ -F[1, {j1}], F[1, {j2}], S[1] ] == -I/Sqrt[2] *
    { {lam * IndexDelta[j1, j2],0},
      {lam * IndexDelta[j1, j2],0} },

  C[ -F[1, {j1}], F[1, {j2}], S[2] ] == -1/Sqrt[2] *
    { {lam IndexDelta[j1, j2],0},
      {-lam IndexDelta[j1, j2],0} }

}

M$LastModelRules = {}

